@@ -1,11 +1,8 @@
 use strict;
 use warnings;
 package Task::Kensho::Scalability;
-BEGIN {
-  $Task::Kensho::Scalability::AUTHORITY = 'cpan:PERIGRIN';
-}
-# git description: v0.35-34-g4d2ee3e
-$Task::Kensho::Scalability::VERSION = '0.36';
+# git description: v0.36-31-g26bf0fc
+$Task::Kensho::Scalability::VERSION = '0.37';
 # ABSTRACT: A Glimpse at an Enlightened Perl: Scalability
 
 __END__
@@ -20,7 +17,7 @@ Task::Kensho::Scalability - A Glimpse at an Enlightened Perl: Scalability
 
 =head1 VERSION
 
-version 0.36
+version 0.37
 
 =head1 SYNOPSIS
 
@@ -69,10 +66,10 @@ facilitates the ease and simplicity the distribution aims to achieve.
 
 =head1 RECOMMENDED MODULES
 
-=head2 L<Task::Kensho::Scalability>: Scalability
-
 =for stopwords Redis
 
+=head2 L<Task::Kensho::Scalability>: Scalability
+
 =head3 L<CHI>
 
 A unified cache interface, like DBI
@@ -118,4 +115,24 @@ This software is copyright (c) 2008 by Chris Prather.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 CONTRIBUTORS
+
+=for stopwords Karen Etheridge Leo Lapworth Chris Nehren
+
+=over 4
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Leo Lapworth <leo@cuckoo.org>
+
+=item *
+
+Chris Nehren <apeiron@cpan.org>
+
+=back
+
 =cut
